herosdevices.hardware.toptica.dlcpro - Heros Devices 0.6.1 documentation

Skip to content
Back to top
View this page

# herosdevices.hardware.toptica.dlcpro

HEROS implementation of the toptica DLC PRO laser driver.

## Module Contents

herosdevices.hardware.toptica.dlcpro.DEFAULT_QUERIES = [['set current', 'dl.cc.current_set', 'mA'], ['actual current', 'dl.cc.current_act', 'mA'],...

  default queries check loop stable parameter values 0:inactive, 1:unstable, 2:stable check object temperature syntax [ [display_name, parameter_id, unit], ]

herosdevices.hardware.toptica.dlcpro.dlcproorders = ('emission_button_enabled', 'interlock_open', 'frontkey_locked', 'emission', 'system_health',...

  Define parameters of the DLCPro and the laser in order to build another function call later

class herosdevices.hardware.toptica.dlcpro.DlcProSource(ip: str = '127.0.0.1', laser: str = 'laser1', queries: list[list[str]] = DEFAULT_QUERIES)

  Reading Toptica DLC Pro parameters via ethernet.

  ip = '127.0.0.1'
  laser = 'laser1'
  queries = [['set current', 'dl.cc.current_set', 'mA'], ['actual current', 'dl.cc.current_act', 'mA'],...
  teardown() → None

    Cleanup at the end.

  property session: toptica.lasersdk.dlcpro.v3_2_0.DLCpro

    Return a dlc objects and connect if necessary.